@@ -14,6 +14,12 @@ import aws_cdk.aws_s3
 import aws_cdk.aws_sns
 import aws_cdk.core
 import aws_cdk.cx_api
-__all__ = []
+import constructs
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-cloudformation", "1.38.0", __name__[0:-6], "aws-cloudformation@1.38.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
